#
#  This file is part of Sequana software
#
#  Copyright (c) 2016-2021 - Sequana Dev Team (https://sequana.readthedocs.io)
#
#  Distributed under the terms of the 3-clause BSD license.
#  The full license is in the LICENSE file, distributed with this software.
#
#  Website:       https://github.com/sequana/sequana
#  Documentation: http://sequana.readthedocs.io
#  Contributors:  https://github.com/sequana/sequana/graphs/contributors
##############################################################################
import rich_click as click
from sequana_pipetools import version

click.rich_click.USE_MARKDOWN = True
click.rich_click.SHOW_METAVARS_COLUMN = False
click.rich_click.APPEND_METAVARS_HELP = True
click.rich_click.STYLE_ERRORS_SUGGESTION = "magenta italic"
click.rich_click.SHOW_ARGUMENTS = True

CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])


@click.command(context_settings=CONTEXT_SETTINGS)
@click.option("--version", is_flag=True)
def main(**kwargs):
    """ """
    if kwargs["version"]:
        print(f"sequana_pipetools v{version}")


if __name__ == "__main__":
    main()



import pkg_resources

try:
    version = pkg_resources.require("sequana_pipetools")[0].version
except pkg_resources.DistributionNotFound:  # pragma: no cover
    version = ">=0.2.0"


from easydev.logging_tools import Logging

logger = Logging("sequana_pipetools", "WARNING")
# To keep the inheritance/propagation of levels. Logging from easydev will do
# the formatting only.
import colorlog

logger = colorlog.getLogger(logger.name)

from .misc import url2hash
from .sequana_manager import SequanaManager #, get_pipeline_location
from .snaketools import (Module, PipelineManager, PipelineManagerDirectory,
                         SequanaConfig)
